@@ -11,6 +11,7 @@ from .deepl import DeepL
 from .detection import single_detection, batch_detection
 from .microsoft import MicrosoftTranslator
 from .papago import PapagoTranslator
+from .libre import LibreTranslator
 
 # TODO: Discussion: These should be declared in setup.cfg, setting them here is redundant
 __author__ = """Nidhal Baccouri"""
@@ -26,6 +27,7 @@ __all__ = [
     "MicrosoftTranslator",
     "QCRI",
     "DeepL",
+    "LibreTranslator"
     "single_detection",
     "batch_detection"
            ]
